@@ -22,54 +22,64 @@
 #include "globus_xio_util.h"
 #include "globus_xio_load.h"
 
-EXTERN_C_BEGIN
+#ifdef __cplusplus
+extern "C" {
+#endif
 
+#ifndef GLOBUS_GLOBAL_DOCUMENT_SET
 /**
  * @mainpage Globus XIO
- *
- * The Globus eXtensible Input Output library.
+ * @copydoc globus_xio
+ */
+#endif
+
+/**
+ * @defgroup globus_xio Globus XIO
+ * @brief eXtensible Input Output library
  *
  * - @ref GLOBUS_XIO_API
- * - @ref GLOBUS_XIO_API_ASSIST 
+ * - @ref GLOBUS_XIO_API_ASSIST
  * - @ref globus_xio_driver
- * - @ref driver_pgm
+ * - @ref globus_xio_driver_programming
  */
 
 /**
- *  @defgroup GLOBUS_XIO_API The globus_xio user API.
+ *  @defgroup GLOBUS_XIO_API Globus XIO API
+ *  @ingroup globus_xio
  */
 
 /**
- *  @defgroup GLOBUS_XIO_API_ASSIST User API Assistance.
- *  \n
+ *  @defgroup GLOBUS_XIO_API_ASSIST XIO Examples
+ *  @ingroup globus_xio
+ *
  *  Help understanding the globus_xio api.
- *  \n
+ *
  */
 /**
  * \addtogroup GLOBUS_XIO_API_ASSIST 
  * 
- *  \par Stack Constuction.
- *  The driver stack that is used for a given xio handle is constructed
+ *  \section globus_xio_stack_construction Stack Construction
+ *  The driver stack that is used for a given XIO handle is constructed
  *  using a globus_xio_stack_t.  Each driver is loaded by name 
  *  and pushed onto a stack.
  * 
+ *  Stack setup example:
  *  \code
- *  stack setup example:
- * 
- *  // First load the drivers
- *  globus_xio_driver_load("tcp", &tcp_driver);
- *  globus_xio_driver_load("gsi", &gsi_driver);
- * 
- *  //build the stack
- *  globus_xio_stack_init(&stack);
- *  globus_xio_stack_push_driver(stack, tcp_driver, NULL);
- *  globus_xio_stack_push_driver(stack, gsi_driver, NULL);
- *  \endcode
+   
+    // First load the drivers
+    globus_xio_driver_load("tcp", &tcp_driver);
+    globus_xio_driver_load("gsi", &gsi_driver);
+   
+    //build the stack
+    globus_xio_stack_init(&stack);
+    globus_xio_stack_push_driver(stack, tcp_driver, NULL);
+    globus_xio_stack_push_driver(stack, gsi_driver, NULL);
+    \endcode
  */
 /**
  *  \addtogroup GLOBUS_XIO_API_ASSIST
  *
- *  \par Servers
+ *  \section globus_xio_servers Servers
  *  A server data structure provides functionality for passive opens.
  *  A server is initialized and bound to a protocol stack and set
  *  of attributes with the function globus_xio_server_create().  Once
@@ -77,29 +87,29 @@ EXTERN_C_BEGIN
  *  will result in an intialized handle which can later be opened.
  *
  *  \code
- *
- *  globus_xio_server_t             server;
- *  globus_xio_attr_t               attr;
- *
- *  globus_xio_attr_init(&attr);
- *  globus_xio_server_create(&server_handle, attr, stack); 
- *  globus_xio_server_accept(&handle, server);
- *
- *  \endcode
+  
+    globus_xio_server_t             server;
+    globus_xio_attr_t               attr;
+  
+    globus_xio_attr_init(&attr);
+    globus_xio_server_create(&server_handle, attr, stack); 
+    globus_xio_server_accept(&handle, server);
+  
+    \endcode
  */
 
 /**
  *  \addtogroup GLOBUS_XIO_API_ASSIST
  *
- *  \par Handle Construction
+ *  \section globus_xio_handle_construction Handle Construction
  *  There are two ways to create a handle.  The first is for use as a 
  *  client (one that is doing an active open).  The function:
  *  globus_xio_handle_create() is used to create such a handle and bind
  *  that handle to a protocol stack.
  *
  *  \code
- *  globus_xio_handle_create(&handle, stack);
- *  \endcode
+    globus_xio_handle_create(&handle, stack);
+    \endcode
  *
  *  The second means of creating a handle is for use as a server (one
  *  that is doing a passive open).  This is created by accepting a
@@ -110,29 +120,31 @@ EXTERN_C_BEGIN
  *  via a call to globus_xio_handle_cntl() described later.
  *
  *  \code
- *  globus_xio_server_accept(&xio_handle, server_handle);
- *  \endcode
+    globus_xio_server_accept(&xio_handle, server_handle);
+    \endcode
  * 
- *  once a handle is intialized the user can call globus_xio_open()
+ *  once a handle is initialized the user can call globus_xio_open()
  *  to begin the open process.
  */
 
 /**
  * @addtogroup GLOBUS_XIO_API_ASSIST
  *
- *  \par Timeouts
+ *  \section globus_xio_timeouts Timeouts
  *  A user can set a timeout value for any io operation.  Each IO 
  *  operation (open close read write) can have its own timeout value.
- *  If no timeout is set the operation will be allowed to infinitly
- *  block.\n
+ *  If no timeout is set the operation will be allowed to infinitely
+ *  block.
+ *
  *  When time expires the outstanding operation is canceled.  If the
  *  timeout callback for the given operation is not NULL it is called first to
  *  notify the user that the operation timed out and give the user a chance to
  *  ignore that timeout.  If canceled, the user will get the callback they 
  *  registered for the operation as well, but it will come with an error
- *  indicating that it has been canceled.\n
- *  It is possiblie that part of an io operation will complete before
- *  the timeout expires.  In this case the opperation can still be 
+ *  indicating that it has been canceled.
+ *
+ *  It is possible that part of an I/O operation will complete before
+ *  the timeout expires.  In this case the operation can still be 
  *  canceled.  The user will receive there IO callback with and 
  *  error set and the length value appropriately set to indicate how
  *  much of the operation completed.
@@ -140,7 +152,7 @@ EXTERN_C_BEGIN
 /**
  * @addtogroup GLOBUS_XIO_API_ASSIST
  *
- * \par Data Desciptor
+ *  \section data_descriptor Data Descriptor
  *  The data descriptor ADT gives the user a means of attaching/extracting
  *  meta data to a read or write operation.\n
  *  Things like offset, out of band message, and other driver specific
@@ -149,14 +161,14 @@ EXTERN_C_BEGIN
  *  globus_xio_write().  Within the globus_xio framework
  *  it is acceptable to pass NULL instead of a valid data_descriptor,
  *
+ *  Example:
  *  \code
- *  ex:
- *  globus_xio_data_descriptor_init(&desc);
- *  globus_xio_data_descriptor_cntl(desc, 
- *      tcp_driver,
- *      GLOBUS_XIO_TCP_SET_SEND_FLAGS,
- *      GLOBUS_XIO_TCP_SEND_OOB);
- *  \endcode
+    globus_xio_data_descriptor_init(&desc);
+    globus_xio_data_descriptor_cntl(desc, 
+        tcp_driver,
+        GLOBUS_XIO_TCP_SET_SEND_FLAGS,
+        GLOBUS_XIO_TCP_SEND_OOB);
+    \endcode
  */
 
 /*************************************************************************
@@ -166,27 +178,30 @@ EXTERN_C_BEGIN
 /**
  * \addtogroup GLOBUS_XIO_API_ASSIST
  *
- *  \par User Attributes
+ *  \section user_attributes User Attributes
  *  Globus XIO uses a single attribute object for all of its functions.
- *  Attributes give an the user an extenable mechanism to alter default
- *  values which control parameters in an operation.\n
- *  In most of the globus xio user api functions a user passes an 
+ *  Attributes give the user an extensible mechanism to alter default
+ *  values which control parameters in an operation.
+ *
+ *  In most of the Globus XIO user API functions a user passes an 
  *  attribute as a parameter.  In many cases the user may ignore the
  *  attribute parameter and just pass in NULL.  However at times the user
  *  will wish to tweak the operation.  The attribute structure is used for
- *  this tweaking.\n
+ *  this tweaking.
+ *
  *  There are only three attribute functions. @ref globus_xio_attr_init 
  *  @ref globus_xio_attr_cntl and @ref globus_xio_attr_destroy.  The
- *  init and destroy functions are very simple and require little explaination.
- *  Before an attribute can be used it must be intialized, and to clean up all
- *  memory associated with it the user must call destroy on it.\n
+ *  init and destroy functions are very simple and require little explanation.
+ *  Before an attribute can be used it must be initialized, and to clean up all
+ *  memory associated with it the user must call destroy on it.
+ *
  *  The function @ref globus_xio_attr_cntl manipulates values in the
  *  attribute.  For more info on it see @ref globus_xio_attr_cntl.
  */
 
 /**
  *  \ingroup GLOBUS_XIO_API
- *  Intialize a globus xio attribute.
+ *  Initialize a Globus XIO attribute.
  *
  *  @param attr
  *         upon return from this function this out parameter will be 
@@ -204,10 +219,10 @@ globus_xio_attr_init(
  *
  *  This function provides a means to access the attr structure.  What
  *  exactly this function does is determined by the value in the parameter
- *  cmd and the value of the patameter driver.  When the driver parameter
- *  is NULL it indicates that this function applies to general globus xio
+ *  cmd and the value of the parameter driver.  When the driver parameter
+ *  is NULL it indicates that this function applies to general Globus XIO
  *  values.  If it is not NULL it indicates that the function will effect 
- *  driver specific values.  Each driver is resonsible for defining its own
+ *  driver specific values.  Each driver is responsible for defining its own
  *  enumeration of values for cmd and the var args associated with that 
  *  command.  
  *
@@ -217,7 +232,7 @@ globus_xio_attr_init(
  *  @param driver
  *          This parameter indicates which driver the user would like
  *          to perform the requested operation.  If this parameter is 
- *          NULL this request will be scoped to general attribure functions.
+ *          NULL this request will be scoped to general attribute functions.
  *
  *  @param cmd
  *         an enum that determines what specific operation the user is 
@@ -298,9 +313,9 @@ globus_result_t
 globus_xio_stack_destroy(
     globus_xio_stack_t                  stack);
 
-/*************************************************************************
+/*-------------------------------------------------------------------------
  *  server 
- ************************************************************************/
+ *-----------------------------------------------------------------------*/
 /**
  *  @ingroup GLOBUS_XIO_API
  *  Callback signature for accept.
@@ -354,8 +369,8 @@ typedef void
  *         will point to a valid server object.
  *
  *  @param server_attr
- *         an attributre structure used to alter the default server 
- *         intialization.  This will mostly be used in a driver specific manner.
+ *         an attribute structure used to alter the default server 
+ *         initialization.  This will mostly be used in a driver specific manner.
  *         can be NULL.
  *
  *  @param stack
@@ -377,7 +392,7 @@ globus_xio_server_create(
  *         An initialized server handle created with globus_xio_server_create()
  *
  *  @param contact_string
- *         an out varibale.  Will point to a newly allocated string on success.
+ *         an out variable.  Will point to a newly allocated string on success.
  *         must be freed by the caller.
  */
 globus_result_t
@@ -410,7 +425,7 @@ globus_xio_server_close(
  *  @ingroup GLOBUS_XIO_API
  *  Touch driver specific information in a server object.
  *
- *  This function allows the user to comunicate directly with a driver
+ *  This function allows the user to communicate directly with a driver
  *  in association with a server object.  The driver defines what operations
  *  can be preformed.
  */
@@ -425,7 +440,7 @@ globus_xio_server_cntl(
  *  @ingroup GLOBUS_XIO_API
  *  Accept a connection
  *
- *  This function will accept a connetion on the given server object
+ *  This function will accept a connection on the given server object
  *  and the parameter out_handle will be valid if the function returns
  *  successfully.
  */
@@ -451,7 +466,7 @@ globus_xio_server_register_accept(
  *  @ingroup GLOBUS_XIO_API
  *  Initialize a handle for client opens
  *
- *  This funtion will initialize a handle for active opens (client side 
+ *  This function will initialize a handle for active opens (client side 
  *  connections).
  * 
  */
@@ -477,14 +492,14 @@ globus_xio_handle_create(
  *         requested.
  *
  *  @param type
- *         The type of opperation that timed out:
+ *         The type of operation that timed out:
  *         GLOBUS_XIO_OPERATION_OPEN
  *         GLOBUS_XIO_OPERATION_CLOSE
  *         GLOBUS_XIO_OPERATION_READ
  *         GLOBUS_XIO_OPERATION_WRITE
  *
  *  @param arg
- *         A user arg threaded throw to the callback.
+ *         A user arg threaded through to the callback.
  */
 
 typedef globus_bool_t
@@ -508,11 +523,11 @@ typedef globus_bool_t
  *  @ingroup GLOBUS_XIO_API
  *
  *  @param data_desc
- *         An out parameter.  The data descriptor to be intialized.
+ *         An out parameter.  The data descriptor to be initialized.
  *
  *  @param handle
  *         The handle this data descriptor will be used with.  This
- *         parametter is require in order to optimize the code 
+ *         parameter is require in order to optimize the code 
  *         handling the data descriptors use.
  */
 globus_result_t
@@ -532,7 +547,7 @@ globus_xio_data_descriptor_destroy(
  *  Touch driver specific data in data descriptors
  *  @ingroup GLOBUS_XIO_API
  * 
- *  This function allows the user to comunicate directly with a driver
+ *  This function allows the user to communicate directly with a driver
  *  in association with a data descriptors.  The driver defines what operations
  *  can be preformed.
  */
@@ -562,10 +577,10 @@ typedef void (*globus_xio_callback_t)(
  *  globus_xio_data_callback_t 
  *  @ingroup GLOBUS_XIO_API
  *
- *  This callback is used for asychronous operations that send or receive
+ *  This callback is used for asynchronous operations that send or receive
  *  data.
  *
- *  on eof, result_t will be of type GLOBUS_XIO_ERROR_EOF
+ *  On EOF, result_t will be of type GLOBUS_XIO_ERROR_EOF
  */
 typedef void (*globus_xio_data_callback_t)(
     globus_xio_handle_t                 handle, 
@@ -580,10 +595,10 @@ typedef void (*globus_xio_data_callback_t)(
  *  globus_xio_iovec_callback_t 
  *  @ingroup GLOBUS_XIO_API
  *
- *  This callback is used for asychronous operations that send or receive
- *  data with an ivec structure.
+ *  This callback is used for asynchronous operations that send or receive
+ *  data with an iovec structure.
  *
- *  on eof, result_t will be of type GLOBUS_XIO_ERROR_EOF
+ *  On EOF, result_t will be of type GLOBUS_XIO_ERROR_EOF
  */
 typedef void (*globus_xio_iovec_callback_t)(
     globus_xio_handle_t                 handle,
@@ -598,7 +613,7 @@ typedef void (*globus_xio_iovec_callback_t)(
  *  @ingroup GLOBUS_XIO_API
  *  Touch driver specific information in a handle object.
  *
- *  This function allows the user to comunicate directly with a driver
+ *  This function allows the user to communicate directly with a driver
  *  in association with a handle object.  The driver defines what operations
  *  can be preformed.
  * 
@@ -622,8 +637,8 @@ globus_xio_handle_cntl(
  * 
  * No operation can be preformed on a handle until it is initialized 
  * and then opened.  If 
- * an already open handle used the information contaned in that handle
- * will be destoyed.
+ * an already open handle used the information contained in that handle
+ * will be destroyed.
  * 
  * @param handle
  *     The handle created with @ref globus_xio_handle_create() or 
@@ -641,7 +656,7 @@ globus_xio_handle_cntl(
  * @param contact_string
  *     An url describing the resource.  NULL is allowed.
  *     Drivers interpret the various parts
- *     of this url as descibed in their documentation.  An alternative
+ *     of this url as described in their documentation.  An alternative
  *     form is also supported:  if contact_string does not specify a scheme
  *     (e.g. http://) and it contains a ':', it will be parsed as a host:port
  *     pair.  if it does not contain a ':', it will be parsed as the path
@@ -663,7 +678,7 @@ globus_xio_handle_cntl(
  *          \<hostname\> | \<dotted quad\> | "[" \<ipv6 address\> "]"
  *    </pre>
  *
- *    Except for use as the above delimeters, the following special characters
+ *    Except for use as the above delimiters, the following special characters
  *    MUST be encoded with the \%HH format where H == hex char.
  *    
  *    <pre>
@@ -816,7 +831,7 @@ globus_xio_server_cancel_accept(
  *  Close a handle
  *  @ingroup GLOBUS_XIO_API
  * 
- *  This functions servers as a destoy for the handle.  As soon as the
+ *  This functions servers as a destroy for the handle.  As soon as the
  *  operations completes (the callback is called).  The handle is
  *  destroyed.
  *
@@ -854,19 +869,19 @@ globus_xio_close(
  *  Signals are not implemented in the first release.
  *  =================================================
  *
- *  Signals in globus xio give the user a means of requesting 
+ *  Signals in Globus XIO give the user a means of requesting 
  *  notification when given things in the system change.  
  *
  *  For example:
  *  It may be useful for the user of globus_xio to know when/if the 
  *  optimal post buffer size changes.  The optimal post buffer size is
- *  a value that tells the user the best posible length of a buffer to 
- *  post for an io operation.  This value is mutable and can be changed
+ *  a value that tells the user the best possible length of a buffer to 
+ *  post for an I/O operation.  This value is mutable and can be changed
  *  by events internal to globus_xio of which the user is unaware.
  *  The signal API allows the user to register for notification of when
  *  this value changes.
  *
- *  GlobusXIO enumerates the signal types for which the user can register.  
+ *  Globus XIO enumerates the signal types for which the user can register.  
  *  One of these types is GLOBUS_XIO_DRIVER_SPECIFIC.  This type allows
  *  the user to catch driver specific signals.  A driver specific signal
  *  example could be when the TCP window size changes.  Only a TCP driver
@@ -896,7 +911,7 @@ enum globus_xio_signal_type_t
  *         The handle associated with the event.
  * 
  *  @param signal_type
- *         The type of signal that occured.
+ *         The type of signal that occurred.
  *
  *  @param driver
  *         The driver that caused this event.  If it is not a driver
@@ -910,7 +925,7 @@ typedef void
  *  Register a signal listener.
  *  @ingroup GLOBUS_XIO_API
  *
- *  Reqest notification when event change in the system relating
+ *  Request notification when event change in the system relating
  *  to a given handle.
  *
  *  @param handle
@@ -926,7 +941,7 @@ typedef void
  *         must be called once for every driver of interest.
  *
  *  @param callback
- *         The funciton to be called when the given events occur.
+ *         The function to be called when the given events occur.
  *
  *  @param user_arg
  *         A user pointed threaded through to the callback.
@@ -941,7 +956,7 @@ globus_xio_handle_register_signal_handler(
  *  Register a signal listener.
  *  @ingroup GLOBUS_XIO_API
  *
- *  Reqest notification when event change in the system relating
+ *  Request notification when event change in the system relating
  *  to a given factory.
  *
  *  @param factory
@@ -957,7 +972,7 @@ globus_xio_handle_register_signal_handler(
  *         must be called once for every driver of interest.
  *
  *  @param callback
- *         The funciton to be called when the given events occur.
+ *         The function to be called when the given events occur.
  *
  *  @param user_arg
  *         A user pointed threaded through to the callback.
@@ -1046,6 +1061,8 @@ globus_xio_handle_create_from_url(
     globus_xio_attr_t               attr,
     char *                          param_string);
 
-EXTERN_C_END
+#ifdef __cplusplus
+}
+#endif
 
 #endif
