@@ -925,7 +925,7 @@ globus_l_xio_driver_open_op_kickout(
     GlobusXIODebugInternalExit();
 }
 
-/**************************************************************************
+/*-************************************************************************
  *                  context driver api funcitons
  *                  ----------------------------
  *************************************************************************/
@@ -998,7 +998,7 @@ globus_i_xio_context_create(
     return xio_context;
 }
 
-/**************************************************************************
+/*-************************************************************************
  *                  macro wrapper functions
  *                  -----------------------
  *
@@ -1461,15 +1461,7 @@ globus_xio_driver_attr_cntl(
         goto err;
     }
 
-#   ifdef HAVE_STDARG_H
-    {
-        va_start(ap, cmd);
-    }
-#   else
-    {
-        va_start(ap);
-    }
-#   endif
+    va_start(ap, cmd);
 
     prev_ndx = op->entry[op->ndx - 1].prev_ndx;
 
@@ -1512,15 +1504,7 @@ globus_xio_driver_data_descriptor_cntl(
         goto err;
     }
 
-#   ifdef HAVE_STDARG_H
-    {
-        va_start(ap, cmd);
-    }
-#   else
-    {
-        va_start(ap);
-    }
-#   endif
+    va_start(ap, cmd);
 
     res = globus_i_xio_driver_dd_cntl(
         op, driver, GLOBUS_XIO_OPERATION_TYPE_DD, cmd, ap);
@@ -1740,15 +1724,7 @@ globus_xio_driver_handle_cntl(
         res = GlobusXIOErrorParameter("op");
         goto err;
     }
-#   ifdef HAVE_STDARG_H
-    {
-        va_start(ap, cmd);
-    }
-#   else
-    {
-        va_start(ap);
-    }
-#   endif
+    va_start(ap, cmd);
 
     if(driver == GLOBUS_XIO_QUERY)
     {
@@ -1901,7 +1877,7 @@ globus_xio_driver_eof_received(
     return received;
 }
 
-/***************************************************************************
+/*-*************************************************************************
  *                      driver setup functions
  *                      ----------------------
  **************************************************************************/
@@ -2158,7 +2134,7 @@ globus_xio_operation_refresh_timeout(
     op->progress = GLOBUS_TRUE;
 }
 
-/** returns true if operation already canceled */
+/* returns true if operation already canceled */
 globus_bool_t
 globus_xio_operation_enable_cancel(
     globus_xio_operation_t              op,
@@ -2284,15 +2260,7 @@ globus_xio_operation_attr_cntl(
         goto error_param;
     }
 
-#   ifdef HAVE_STDARG_H
-    {
-        va_start(ap, cmd);
-    }
-#   else
-    {
-        va_start(ap);
-    }
-#   endif
+    va_start(ap, cmd);
 
     switch(cmd)
     {
